@@ -38,23 +38,21 @@ from . import optimizer, rule
 from .combination import Product, Reducer, Sum
 from .function import (
     GIBBON,
-    AcquisitionFunction,
-    AcquisitionFunctionBuilder,
     AugmentedExpectedImprovement,
     BatchMonteCarloExpectedHypervolumeImprovement,
     BatchMonteCarloExpectedImprovement,
+    ExpectedConstrainedHypervolumeImprovement,
     ExpectedConstrainedImprovement,
     ExpectedHypervolumeImprovement,
     ExpectedImprovement,
-    GreedyAcquisitionFunctionBuilder,
     LocalPenalizationAcquisitionFunction,
     MinValueEntropySearch,
     NegativeLowerConfidenceBound,
     NegativePredictiveMean,
+    PredictiveVariance,
     ProbabilityOfFeasibility,
-    SingleModelAcquisitionBuilder,
-    SingleModelGreedyAcquisitionBuilder,
     augmented_expected_improvement,
+    batch_ehvi,
     expected_hv_improvement,
     expected_improvement,
     gibbon_quality_term,
@@ -62,9 +60,20 @@ from .function import (
     hard_local_penalizer,
     lower_confidence_bound,
     min_value_entropy_search,
+    predictive_variance,
     probability_of_feasibility,
     soft_local_penalizer,
 )
+from .interface import (
+    AcquisitionFunction,
+    AcquisitionFunctionBuilder,
+    AcquisitionFunctionClass,
+    GreedyAcquisitionFunctionBuilder,
+    PenalizationFunction,
+    SingleModelAcquisitionBuilder,
+    SingleModelGreedyAcquisitionBuilder,
+    UpdatablePenalizationFunction,
+)
 from .sampler import (
     BatchReparametrizationSampler,
     ExactThompsonSampler,
