@@ -18,5 +18,5 @@ creating :class:`TrainableProbabilisticModel`\ s from config.
 """
 
 from . import gpflow, gpflux, optimizer
-from .config import ModelConfig, ModelSpec, create_model
+from .config import ModelConfig, ModelRegistry, ModelSpec, create_model
 from .interfaces import ModelStack, ProbabilisticModel, TrainableProbabilisticModel
