@@ -26,7 +26,7 @@ from ...data import Dataset
 from ...types import TensorType
 from ...utils import DEFAULTS, jit
 from ..interfaces import TrainableProbabilisticModel
-from ..optimizer import Optimizer, TFOptimizer
+from ..optimizer import BatchOptimizer, Optimizer
 from .interface import GPflowPredictor
 from .utils import assert_data_is_compatible, randomize_hyperparameters, squeeze_hyperparameters
 
@@ -71,7 +71,7 @@ class GaussianProcessRegression(GPflowPredictor, TrainableProbabilisticModel):
         # GPflow stores the data in Tensors. However, since we want to be able to update the data
         # without having to retrace the acquisition functions, put it in Variables instead.
         # Data has to be stored in variables with dynamic shape to allow for changes
-        # Sometimes, for instance after serialization-deserialization, the shape can be overriden
+        # Sometimes, for instance after serialization-deserialization, the shape can be overridden
         # Thus here we ensure data is stored in dynamic shape Variables
 
         if all(isinstance(x, tf.Variable) and x.shape[0] is None for x in self._model.data):
@@ -247,12 +247,12 @@ class SparseVariational(GPflowPredictor, TrainableProbabilisticModel):
         """
         :param model: The underlying GPflow sparse variational model.
         :param optimizer: The optimizer with which to train the model. Defaults to
-            :class:`~trieste.models.optimizer.TFOptimizer` with :class:`~tf.optimizers.Adam` with
+            :class:`~trieste.models.optimizer.BatchOptimizer` with :class:`~tf.optimizers.Adam` with
             batch size 100.
         """
 
         if optimizer is None:
-            optimizer = TFOptimizer(tf.optimizers.Adam(), batch_size=100)
+            optimizer = BatchOptimizer(tf.optimizers.Adam(), batch_size=100)
 
         super().__init__(optimizer)
         self._model = model
@@ -326,22 +326,31 @@ class VariationalGaussianProcess(GPflowPredictor, TrainableProbabilisticModel):
             :class:`~trieste.models.optimizer.Optimizer` with :class:`~gpflow.optimizers.Scipy`.
         :param use_natgrads: If True then alternate model optimization steps with natural
             gradient updates. Note that natural gradients requires
-            an :class:`~trieste.models.optimizer.Optimizer` optimizer.
+            a :class:`~trieste.models.optimizer.BatchOptimizer` wrapper with
+            :class:`~tf.optimizers.Optimizer` optimizer.
         :natgrad_gamma: Gamma parameter for the natural gradient optimizer.
         :raise ValueError (or InvalidArgumentError): If ``model``'s :attr:`q_sqrt` is not rank 3
             or if attempting to combine natural gradients with a :class:`~gpflow.optimizers.Scipy`
             optimizer.
         """
         tf.debugging.assert_rank(model.q_sqrt, 3)
+
+        if optimizer is None and not use_natgrads:
+            optimizer = Optimizer(gpflow.optimizers.Scipy())
+        elif optimizer is None and use_natgrads:
+            optimizer = BatchOptimizer(tf.optimizers.Adam(), batch_size=100)
+
         super().__init__(optimizer)
         self._model = model
 
         if use_natgrads:
-            if not isinstance(self._optimizer, TFOptimizer):
+            if not isinstance(self._optimizer, BatchOptimizer) or not isinstance(
+                self._optimizer.optimizer, tf.optimizers.Optimizer
+            ):
                 raise ValueError(
                     f"""
-                    Natgrads can only be used alongside an optimizer from tf.optimizers however
-                    received f{self._optimizer}
+                    Natgrads can only be used with a BatchOptimizer wrapper using an instance of
+                    tf.optimizers.Optimizer, however received f{self._optimizer}.
                     """
                 )
 
@@ -401,7 +410,7 @@ class VariationalGaussianProcess(GPflowPredictor, TrainableProbabilisticModel):
         f_mu, f_cov = self.model.predict_f(dataset.query_points, full_cov=True)  # [N, L], [L, N, N]
 
         # GPflow's VGP model is hard-coded to use the whitened representation, i.e.
-        # q_mu and q_sqrt parametrise q(v), and u = f(X) = L v, where L = cholesky(K(X, X))
+        # q_mu and q_sqrt parametrize q(v), and u = f(X) = L v, where L = cholesky(K(X, X))
         # Hence we need to back-transform from f_mu and f_cov to obtain the updated
         # new_q_mu and new_q_sqrt:
         Knn = model.kernel(dataset.query_points, full_cov=True)  # [N, N]
